@@ -12,10 +12,10 @@ sub plug_in_example_oo {
   
   my $bg=new Layer($img,300,200,RGB_IMAGE,"Background",100,NORMAL_MODE);
   
-  Palette::set_background([200,200,100]);
+  Palette->set_background([200,200,100]);
   
   $bg->fill(BG_IMAGE_FILL);
-#  Palette::set_background([200,100,200]);
+#  Palette->set_background([200,100,200]);
 #  gimp_drawable_fill ($bg,BG_IMAGE_FILL);
   $img->add_layer($bg,1);
   
